@@ -1,6 +1,12 @@
 # -*- coding: utf-8 -*-
 import os
 import sys
+import pkg_resources
+
+for p in sys.path:
+    if p.endswith('.egg') and p not in pkg_resources.working_set.entries:
+        pkg_resources.working_set.add_entry(p)
+del p
 
 def get_settings(mod_name=None, apps=(), middlewares=()):
     mod_name = mod_name or os.environ.get('DJANGO_SETTINGS_MODULE', 'settings')
